@@ -59,4 +59,10 @@ class DescribeRestoreRangeInfoRequest(RpcRequest):
 		return self.get_query_params().get('OwnerId')
 
 	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_RecentlyRestore(self):
+		return self.get_query_params().get('RecentlyRestore')
+
+	def set_RecentlyRestore(self,RecentlyRestore):
+		self.add_query_param('RecentlyRestore',RecentlyRestore)
\ No newline at end of file
