@@ -31,6 +31,12 @@ class ModifyBackupStrategyRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_BackupLogIntervalSeconds(self):
+		return self.get_query_params().get('BackupLogIntervalSeconds')
+
+	def set_BackupLogIntervalSeconds(self,BackupLogIntervalSeconds):
+		self.add_query_param('BackupLogIntervalSeconds',BackupLogIntervalSeconds)
+
 	def get_ClientToken(self):
 		return self.get_query_params().get('ClientToken')
 
